package com.me.pacman;

import java.util.Arrays;

public class Sound {

    public enum Effect {
        BEGINNING,
        BEGINNING_ALT,
        FRIGHT,
        CHOMP_1,
        CHOMP_2,
        DEATH,
        EAT_FRUIT,
        EAT_GHOST,
        EXTRA_LIFE,
        RETURN_BASE,
        SIREN,
        SIREN_FAST,
        SIREN_FASTER,
        SIREN_FASTEST
    }

    private float volume = 1.0f;
    private boolean muted;

    private PacDude game;
    private long[] playing;

    public Sound(PacDude game) {
        this.game = game;
        this.playing = new long[Effect.values().length];
        Arrays.fill(this.playing, -1);
    }

    private float volume() {
        return muted? 0f : volume;
    }

    public void setMuted(boolean muted) {
        this.muted = muted;
    }

    public long play(Effect effect) {
        return muted? -1 : getSound(effect).play(volume());
    }

    public long loop(Effect effect) {
        if (muted) {
            return -1;
        }
        long id = getSound(effect).loop(volume());
        playing[effect.ordinal()] = id;
        return id;
    }

    public void stop(Effect effect) {
        long id = playing[effect.ordinal()];
        com.badlogic.gdx.audio.Sound sound = getSound(effect);
        sound.stop(id);
        playing[effect.ordinal()] = -1;
    }

    public void stopAll() {
        for (int i = 0; i < playing.length; i++) {
            if (playing[i] < 0) {
                continue;
            }
            getSound(Effect.values()[i]).stop(playing[i]);
            playing[i] = -1;
        }
    }

    private com.badlogic.gdx.audio.Sound getSound(Effect effect) {
        Assets a = game.assets;
        switch (effect) {
            case BEGINNING:
                return a.beginning;
            case BEGINNING_ALT:
                return a.beginning_alt;
            case FRIGHT:
                return a.fright;
            case CHOMP_1:
                return a.chomp_1;
            case CHOMP_2:
                return a.chomp_2;
            case DEATH:
                return a.deathSound;
            case EAT_FRUIT:
                return a.eat_fruit;
            case EAT_GHOST:
                return a.eat_ghost;
            case EXTRA_LIFE:
                return a.extra_life;
            case RETURN_BASE:
                return a.return_base;
            case SIREN:
                return a.siren;
            case SIREN_FAST:
                return a.siren_fast;
            case SIREN_FASTER:
                return a.siren_faster;
            case SIREN_FASTEST:
                return a.siren_fastest;
        }
        return null;
    }

}
